.. template taken from Pandas

.. module:: scipy

*******************
SciPy documentation
*******************

**Date**: |today| **Version**: |version|

**Download documentation**: https://docs.scipy.org/doc/

**Useful links**:
`Install <https://scipy.org/install/>`__ |
`Source Repository <https://github.com/scipy/scipy>`__ |
`Issues & Ideas <https://github.com/scipy/scipy/issues>`__ |
`Q&A Support <https://stackoverflow.com/questions/tagged/scipy>`__ |
`Mailing List <https://mail.python.org/mailman3/lists/scipy-dev.python.org/>`__

**SciPy** (pronounced "Sigh Pie") is an open-source software for mathematics,
science, and engineering.

.. panels::
    :card: + intro-card text-center
    :column: col-lg-6 col-md-6 col-sm-6 col-xs-12 d-flex

    ---
    :img-top: _static/index_getting_started.png

    Getting started
    ^^^^^^^^^^^^^^^

    New to *SciPy*? Check out the getting started guides. They contain an
    introduction to *SciPy'* main concepts and links to additional tutorials.

    +++

    .. link-button:: getting_started_ref
            :type: ref
            :text: To the getting started guides
            :classes: btn-block btn-secondary stretched-link

    ---
    :img-top: _static/index_user_guide.png

    User guide
    ^^^^^^^^^^

    The user guide provides in-depth information on the
    key concepts of SciPy with useful background information and explanation.

    +++

    .. link-button:: user_guide
            :type: ref
            :text: To the user guide
            :classes: btn-block btn-secondary stretched-link

    ---
    :img-top: _static/index_api.png

    API reference
    ^^^^^^^^^^^^^

    The reference guide contains a detailed description of
    the SciPy API. The reference describes how the methods work and which parameters can
    be used. It assumes that you have an understanding of the key concepts.

    +++

    .. link-button:: scipy-api
            :type: ref
            :text: To the reference guide
            :classes: btn-block btn-secondary stretched-link

    ---
    :img-top: _static/index_contribute.png

    Developer guide
    ^^^^^^^^^^^^^^^

    Saw a typo in the documentation? Want to improve
    existing functionalities? The contributing guidelines will guide
    you through the process of improving SciPy.

    +++

    .. link-button:: scipy-development
            :type: ref
            :text: To the development guide
            :classes: btn-block btn-secondary stretched-link

.. toctree::
   :maxdepth: 1
   :hidden:

   Getting started <getting_started>
   User Guide <tutorial/index>
   API reference <reference/index>
   Development <dev/index>
   Release notes <release>
